@@ -1,11 +1,11 @@
-use age::armor::{ArmoredReader, ArmoredWriter, Format};
-use age::Decryptor;
-use anyhow::{anyhow, Context, Result};
-use secrecy::{ExposeSecret, SecretString};
-
 use std::io::{Read, Write};
 use std::path::Path;
 
+use age::armor::{ArmoredReader, ArmoredWriter, Format};
+use age::{Decryptor, IdentityFileEntry};
+use anyhow::{anyhow, Context, Result};
+use secrecy::{ExposeSecret, SecretString};
+
 use crate::kbs2::agent;
 use crate::kbs2::config;
 use crate::kbs2::record::Record;
@@ -68,12 +68,16 @@ impl RageLib {
 
             let client = agent::Client::new().with_context(|| "failed to connect to kbs2 agent")?;
 
-            if !client.query_key(&config.keyfile)? {
-                client.add_key(&config.keyfile, util::get_password(None, &config.pinentry)?)?;
+            if !client.query_key(&config.public_key)? {
+                client.add_key(
+                    &config.public_key,
+                    &config.keyfile,
+                    util::get_password(None, &config.pinentry)?,
+                )?;
             }
 
             let unwrapped_key = client
-                .get_key(&config.keyfile)
+                .get_key(&config.public_key)
                 .with_context(|| format!("agent has no unwrapped key for {}", config.keyfile))?;
 
             log::debug!("parsing unwrapped key");
@@ -91,6 +95,15 @@ impl RageLib {
             ));
         }
 
+        let identities = identities
+            .into_iter()
+            .map(|i| match i {
+                // NOTE(ww): We're not using the plugin feature of the `age` crate,
+                // so this is the only variant.
+                IdentityFileEntry::Native(i) => i,
+            })
+            .collect();
+
         Ok(RageLib { pubkey, identities })
     }
 }
@@ -206,18 +219,8 @@ impl Backend for RageLib {
 
         let mut decrypted = String::new();
 
-        // NOTE(ww): The age API changed here from `&[Identity]` to
-        // `impl Iterator<Item = Box<dyn Identity>>`, which changed the `decrypt`
-        // from a borrow to a stolen ownership of the identity list.
-        // So we do a funky box clone thing below.
         decryptor
-            .decrypt(
-                self.identities
-                    .iter()
-                    .cloned()
-                    .map(Box::new)
-                    .map(|i| i as Box<dyn age::Identity>),
-            )
+            .decrypt(self.identities.iter().map(|i| i as &dyn age::Identity))
             .map_err(|e| anyhow!("unable to decrypt (backend reports: {:?})", e))
             .and_then(|mut r| {
                 r.read_to_string(&mut decrypted)
